@@ -1,6 +1,6 @@
 use std::{sync::Arc};
 
-use crate::hashed_password::BaseHashedPassword;
+use crate::hashed_password::{BaseHashedPassword, self};
 
 use super::hashed_password::HashedPassword;
 
@@ -19,12 +19,13 @@ impl ClearTextPassword for BaseClearTextPassword {
     }
 
     fn hashed_password(&self) -> Result<Arc<dyn HashedPassword>, std::io::Error> { 
-        Ok(Arc::new(BaseHashedPassword{}))
+        let hashed_password = BaseHashedPassword::new()?;
+        Ok(Arc::new(hashed_password))
     }
 }
 
 impl BaseClearTextPassword { 
-    pub fn new(text: String) -> Self { 
-        BaseClearTextPassword{_text: text}
+    pub fn new(text: String) -> Result<Self, std::io::Error> { 
+        Ok(BaseClearTextPassword{_text: text})
     }
 }
