@@ -4,8 +4,7 @@ use crate::{token::Token, hashed_password::HashedPassword, public_key::PublicKey
 
 
 pub trait User { 
-    fn authenticate(&self, clear_text_password: Arc<dyn ClearTextPassword>) -> Result<(), std::io::Error>;
-    fn token(&self) -> Token;
+    fn authenticate(&self, clear_text_password: Arc<dyn ClearTextPassword>) -> Result<Token, std::io::Error>;
     fn hashed_password(&self) -> Arc<dyn HashedPassword>;
 }
 
@@ -15,12 +14,8 @@ pub struct BaseUser {
 }
 
 impl User for BaseUser { 
-    fn authenticate(&self, clear_text_password: Arc<dyn ClearTextPassword>) -> Result<(), std::io::Error> { 
-        Ok(())
-    }
-
-    fn token(&self) -> Token {
-        Token::new(String::from("some_token"))
+    fn authenticate(&self, clear_text_password: Arc<dyn ClearTextPassword>) -> Result<Token, std::io::Error> { 
+        Ok(Token::new(String::from("some_token")))
     }
 
     fn hashed_password(&self) -> Arc<dyn HashedPassword> { 
